==> haskell-data-accessor-transformers-0.2.1.7-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-transformers
version: 0.2.1.7
id: data-accessor-transformers-0.2.1.7-1WdBkBlIKdD2SkmG279Cih
key: data-accessor-transformers-0.2.1.7-1WdBkBlIKdD2SkmG279Cih
license: BSD-3-Clause
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Use Accessor to access state in transformers State monad
description:
    Use Accessor to access state in transformers State monad
category: Data
abi: 70ed74abb32eb721bf9d67387bcaf456
exposed: True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State
hidden-modules: Data.Accessor.Monad.Trans.Example
import-dirs: /usr/lib/ghc-8.6.3/site-local/data-accessor-transformers-0.2.1.7
library-dirs: /usr/lib/ghc-8.6.3/site-local/data-accessor-transformers-0.2.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/data-accessor-transformers-0.2.1.7
hs-libraries: HSdata-accessor-transformers-0.2.1.7-1WdBkBlIKdD2SkmG279Cih
depends:
    base-4.12.0.0 data-accessor-0.2.2.8-32riD7VTnO2INniai0g3x5
    transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-transformers-0.2.1.7-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-transformers
version: 0.2.1.7
id: data-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
key: data-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
license: BSD-3-Clause
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Use Accessor to access state in transformers State monad
description:
    Use Accessor to access state in transformers State monad
category: Data
abi: 06d102ed0a188977be033843aa1427e9
exposed: True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State
hidden-modules: Data.Accessor.Monad.Trans.Example
import-dirs: /usr/lib/ghc-8.6.4/site-local/data-accessor-transformers-0.2.1.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/data-accessor-transformers-0.2.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/data-accessor-transformers-0.2.1.7
hs-libraries: HSdata-accessor-transformers-0.2.1.7-5wbZaRH8II89QeXVhYgfQ4
depends:
    base-4.12.0.0 data-accessor-0.2.2.8-AYq93Bw1A2YHILUYropyUn
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
